#
# Licensed to the Apache Software Foundation (ASF) under one or more
# contributor license agreements.  See the NOTICE file distributed with
# this work for additional information regarding copyright ownership.
# The ASF licenses this file to You under the Apache License, Version 2.0
# (the "License"); you may not use this file except in compliance with
# the License.  You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Make sure you've followed the instructions on `RELEASING/README.md`
# and are on the correct branch
cd ${SUPERSET_REPO_DIR}
git branch
rm superset/static/assets/*
cd superset-frontend/
npm ci && npm run build
cd ../
echo "----------------------"
echo "Compiling translations"
echo "----------------------"
flask fab babel-compile --target superset/translations
echo "----------------------"
echo "Creating distribution "
echo "----------------------"
python setup.py sdist
echo "RUN: twine upload dist/apache-superset-{SUPERSET_VERSION}.tar.gz"
